@@ -10,6 +10,10 @@ and :rst:dir:`autoflag` for documenting :class:`Flags <enum.Flag>`.
 It behaves much like :rst:dir:`autoclass` and :rst:dir:`autofunction`.
 
 See also https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html.
+
+.. versionchanged:: 0.4.0
+
+	Added :class:`~.PyEnumXRefRole` and :rst:role:`py:enum:mem`.
 """
 #
 #  Copyright (c) 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -70,8 +74,8 @@ from sphinx.domains.python import PyClasslike, PyXRefRole
 from sphinx.environment import BuildEnvironment
 from sphinx.ext.autodoc import ALL, AttributeDocumenter, ClassDocumenter, Documenter
 from sphinx.locale import _
-from sphinx_toolbox.autodoc_helpers import begin_generate
-from sphinx_toolbox.autodoc_typehints import format_annotation
+from sphinx_toolbox.more_autodoc.typehints import format_annotation
+from sphinx_toolbox.utils import begin_generate
 
 # this package
 from enum_tools import __version__, documentation
@@ -362,6 +366,8 @@ class EnumMemberDocumenter(AttributeDocumenter):
 class PyEnumXRefRole(PyXRefRole):
 	"""
 	XRefRole for Enum/Flag members.
+
+	.. versionadded:: 0.4.0
 	"""
 
 	def process_link(
@@ -373,12 +379,12 @@ class PyEnumXRefRole(PyXRefRole):
 			target: str,
 			) -> Tuple[str, str]:
 
-		refnode['py:module'] = env.ref_context.get('py:module')
-		refnode['py:class'] = env.ref_context.get('py:class')
+		refnode["py:module"] = env.ref_context.get("py:module")
+		refnode["py:class"] = env.ref_context.get("py:class")
 
 		if not has_explicit_title:
 			title = title.lstrip('.')  # only has a meaning for the target
-			target = target.lstrip('~+')  # only has a meaning for the title
+			target = target.lstrip("~+")  # only has a meaning for the title
 			# if the first character is a tilde, don't display the module/class
 			# parts of the contents
 
@@ -395,7 +401,7 @@ class PyEnumXRefRole(PyXRefRole):
 		# else search builtins first
 		if target[0:1] == '.':
 			target = target[1:]
-			refnode['refspecific'] = True
+			refnode["refspecific"] = True
 
 		return title, target
 
